pub fn container<R>(
ui: &mut Ui,
id: impl Into<String>,
add_contents: impl FnOnce(&mut Ui) -> R,
) -> RExpand description
Run a closure within a container scope with an explicit id.
The container is registered as a widget so it is discoverable via parent() and
children().